@@ -1,5 +1,4 @@
 import subprocess
-
 import sys
 
 
@@ -8,21 +7,22 @@ class CommandError(Exception):
     Error raised when a command being executed returns an error
     """
 
-    pass
 
-
-def execute(command, exit_codes=[0]):
+def execute(command, exit_codes=None):
     """Execute provided command returning the stdout
     Args:
         command (list[str]): list of tokens to execute as your command.
         exit_codes (list[int]): exit codes which do not indicate error.
-        subprocess_mod (module): Defaults to pythons subprocess module but you can optionally pass in
-        another. This is mostly for testing purposes
+        subprocess_mod (module): Defaults to pythons subprocess module but you can optionally pass
+        in another. This is mostly for testing purposes
     Returns:
         str - Stdout of the command passed in. This will be Unicode for python < 3. Str for python 3
     Raises:
         ValueError if there is a error running the command
     """
+    if exit_codes is None:
+        exit_codes = [0]
+
     stdout_pipe = subprocess.PIPE
     process = subprocess.Popen(command, stdout=stdout_pipe, stderr=stdout_pipe)
     try:
@@ -53,8 +53,7 @@ def run_command_for_code(command):
     """
     process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     process.communicate()
-    exit_code = process.returncode
-    return exit_code
+    return process.returncode
 
 
 def _ensure_unicode(text):
@@ -67,5 +66,4 @@ def _ensure_unicode(text):
     """
     if isinstance(text, bytes):
         return text.decode(sys.getfilesystemencoding(), "replace")
-    else:
-        return text
+    return text
