@@ -16,7 +16,10 @@ from diff_cover.report_generator import (
     MarkdownReportGenerator,
     StringReportGenerator,
 )
-from diff_cover.violationsreporters.violations_reporter import XmlCoverageReporter
+from diff_cover.violationsreporters.violations_reporter import (
+    LcovCoverageReporter,
+    XmlCoverageReporter,
+)
 
 HTML_REPORT_HELP = "Diff coverage HTML output"
 JSON_REPORT_HELP = "Diff coverage JSON output"
@@ -30,8 +33,9 @@ IGNORE_STAGED_HELP = "Ignores staged changes"
 IGNORE_UNSTAGED_HELP = "Ignores unstaged changes"
 IGNORE_WHITESPACE = "When getting a diff ignore any and all whitespace"
 EXCLUDE_HELP = "Exclude files, more patterns supported"
+INCLUDE_HELP = "Files to include (glob pattern)"
 SRC_ROOTS_HELP = "List of source directories (only for jacoco coverage reports)"
-COVERAGE_XML_HELP = "XML coverage report"
+COVERAGE_FILE_HELP = "coverage report (XML or lcov.info)"
 DIFF_RANGE_NOTATION_HELP = (
     "Git diff range notation to use when comparing branches, defaults to '...'"
 )
@@ -49,19 +53,19 @@ def parse_coverage_args(argv):
     valid options:
 
         {
-            'coverage_xml': COVERAGE_XML,
+            'coverage_file': COVERAGE_FILE,
             'html_report': None | HTML_REPORT,
             'json_report': None | JSON_REPORT,
             'external_css_file': None | CSS_FILE,
         }
 
-    where `COVERAGE_XML`, `HTML_REPORT`, `JSON_REPORT`, and `CSS_FILE` are paths.
+    where `COVERAGE_FILE`, `HTML_REPORT`, `JSON_REPORT`, and `CSS_FILE` are paths.
 
     The path strings may or may not exist.
     """
     parser = argparse.ArgumentParser(description=DESCRIPTION)
 
-    parser.add_argument("coverage_xml", type=str, help=COVERAGE_XML_HELP, nargs="+")
+    parser.add_argument("coverage_file", type=str, help=COVERAGE_FILE_HELP, nargs="+")
 
     parser.add_argument(
         "--html-report",
@@ -128,6 +132,10 @@ def parse_coverage_args(argv):
         "--exclude", metavar="EXCLUDE", type=str, nargs="+", help=EXCLUDE_HELP
     )
 
+    parser.add_argument(
+        "--include", metavar="INCLUDE", type=str, nargs="+", help=INCLUDE_HELP
+    )
+
     parser.add_argument(
         "--src-roots",
         metavar="DIRECTORY",
@@ -178,7 +186,7 @@ def parse_coverage_args(argv):
 
 
 def generate_coverage_report(
-    coverage_xml,
+    coverage_files,
     compare_branch,
     html_report=None,
     css_file=None,
@@ -188,6 +196,7 @@ def generate_coverage_report(
     ignore_unstaged=False,
     include_untracked=False,
     exclude=None,
+    include=None,
     src_roots=None,
     diff_range_notation=None,
     ignore_whitespace=False,
@@ -204,10 +213,25 @@ def generate_coverage_report(
         ignore_unstaged=ignore_unstaged,
         include_untracked=include_untracked,
         exclude=exclude,
+        include=include,
     )
 
-    xml_roots = [etree.parse(xml_root) for xml_root in coverage_xml]
-    coverage = XmlCoverageReporter(xml_roots, src_roots)
+    xml_roots = [
+        etree.parse(coverage_file)
+        for coverage_file in coverage_files
+        if coverage_file.endswith(".xml")
+    ]
+    lcov_roots = [
+        LcovCoverageReporter.parse(coverage_file)
+        for coverage_file in coverage_files
+        if not coverage_file.endswith(".xml")
+    ]
+    if len(xml_roots) > 0 and len(lcov_roots) > 0:
+        raise ValueError(f"Mixing LCov and XML reports is not supported yet")
+    elif len(xml_roots) > 0:
+        coverage = XmlCoverageReporter(xml_roots, src_roots)
+    else:
+        coverage = LcovCoverageReporter(lcov_roots, src_roots)
 
     # Build a report generator
     if html_report is not None:
@@ -258,7 +282,7 @@ def main(argv=None, directory=None):
     GitPathTool.set_cwd(directory)
     fail_under = arg_dict.get("fail_under")
     percent_covered = generate_coverage_report(
-        arg_dict["coverage_xml"],
+        arg_dict["coverage_file"],
         arg_dict["compare_branch"],
         html_report=arg_dict["html_report"],
         json_report=arg_dict["json_report"],
@@ -268,6 +292,7 @@ def main(argv=None, directory=None):
         ignore_unstaged=arg_dict["ignore_unstaged"],
         include_untracked=arg_dict["include_untracked"],
         exclude=arg_dict["exclude"],
+        include=arg_dict["include"],
         src_roots=arg_dict["src_roots"],
         diff_range_notation=arg_dict["diff_range_notation"],
         ignore_whitespace=arg_dict["ignore_whitespace"],
